from django.apps import apps
from django.urls import include, path
from wbcore.routers import WBCoreRouter

from wbcommission import viewsets

router = WBCoreRouter()

router.register(
    r"rebatemarginalitytable",
    viewsets.RebateProductMarginalityViewSet,
    basename="rebatemarginalitytable",
)
router.register(
    r"rebatetable",
    viewsets.RebatePandasView,
    basename="rebatetable",
)
router.register(
    r"rebate",
    viewsets.RebateModelViewSet,
    basename="rebate",
)
router.register(
    r"commissiontype",
    viewsets.CommissionTypeModelViewSet,
    basename="commissiontype",
)
router.register(
    r"commissiontyperepresentation",
    viewsets.CommissionTypeRepresentationModelViewSet,
    basename="commissiontyperepresentation",
)

if apps.is_installed("wbportfolio"):
    from wbportfolio.viewsets.transactions.claim import ClaimAPIModelViewSet

    router.register(r"claim-api", ClaimAPIModelViewSet, basename="claim-api")

account_router = WBCoreRouter()


urlpatterns = [path("", include(router.urls)), path("account/<int:account_id>/", include(account_router.urls))]



from wbcore.metadata.configs.titles import TitleViewConfig


class RebatePandasViewTitleConfig(TitleViewConfig):
    def get_list_title(self):
        return "Rebates"


class RebateProductMarginalityTitleConfig(TitleViewConfig):
    def get_list_title(self):
        return "Marginality per Product"



from .buttons import *  # noqa
from .rebate import (
    RebateModelViewSet,
    RebatePandasView,
    RebateProductMarginalityViewSet,
)
from .commissions import CommissionTypeRepresentationModelViewSet, CommissionTypeModelViewSet



# Generated by Django 4.2.7 on 2023-11-16 13:54

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wbcommission", "0004_rebate_audit_log"),
    ]

    operations = [
        migrations.AlterField(
            model_name="rebate",
            name="audit_log",
            field=models.JSONField(
                default=dict, encoder=django.core.serializers.json.DjangoJSONEncoder, verbose_name="Audit Log"
            ),
        ),
    ]
